aboutsummaryrefslogtreecommitdiff
path: root/params/network_params.go
diff options
context:
space:
mode:
Diffstat (limited to 'params/network_params.go')
-rw-r--r--params/network_params.go12
1 files changed, 9 insertions, 3 deletions
diff --git a/params/network_params.go b/params/network_params.go
index bba2472..9311b5e 100644
--- a/params/network_params.go
+++ b/params/network_params.go
@@ -53,9 +53,15 @@ const (
// CheckpointProcessConfirmations is the number before a checkpoint is generated
CheckpointProcessConfirmations = 256
// ImmutabilityThreshold is the number of blocks after which a chain segment is
// considered immutable (i.e. soft finality). It is used by the downloader as a
// hard limit against deep ancestors, by the blockchain against deep reorgs, by
- // the freezer as the cutoff treshold and by clique as the snapshot trust limit.
- ImmutabilityThreshold = 90000
+ // the freezer as the cutoff threshold and by clique as the snapshot trust limit.
+ FullImmutabilityThreshold = 90000
+
+ // LightImmutabilityThreshold is the number of blocks after which a header chain
+ // segment is considered immutable for light client(i.e. soft finality). It is used by
+ // the downloader as a hard limit against deep ancestors, by the blockchain against deep
+ // reorgs, by the light pruner as the pruning validity guarantee.
+ LightImmutabilityThreshold = 30000
)
@@ -53,9 +53,15 @@ const (
// CheckpointProcessConfirmations is the number before a checkpoint is generated
CheckpointProcessConfirmations = 256
- // ImmutabilityThreshold is the number of blocks after which a chain segment is
+ // FullImmutabilityThreshold is the number of blocks after which a chain segment is
// considered immutable (i.e. soft finality). It is used by the downloader as a
// hard limit against deep ancestors, by the blockchain against deep reorgs, by